local addonName, QD = ...; -- gets addon-local variables

local L = QD.LOCALIZATION;
local act = QD.actionID;


function QuiDicit.DialogColor_SetFields(action, name, group, color)
    QuiDicit_DialogColorType:SetText(action);
    QuiDicit_DialogColor_EditBoxCharacter:SetText(name);
    QuiDicit_DialogColor_EditBoxGroup:SetText(group);
    QuiDicit_DialogColor_EditBoxHex:SetText(color);

    QuiDicit.DialogColor_UpdateColors(color);
end

function QuiDicit.DialogColor_UpdateColors(color, sender)
    if( QuiDicit_DialogColorUpdate:GetText() == "0" ) then
        QuiDicit_DialogColorUpdate:SetText("1");

        -- get color values
        local rperc,gperc,bperc = QuiDicit.HexToRGBPerc(color);
        local r,g,b = QuiDicit.HexToRGB(color);

        -- Set RGBHex Box
        if ( not sender or not (sender:GetName() == "QuiDicit_DialogColor_EditBoxHex") ) then
            QuiDicit_DialogColor_EditBoxHex:SetText(color);
        end

        -- ColorSelect
        if ( not sender or not (sender:GetName() == "QuiDicit_DialogColor_ColorSelect") ) then
            QuiDicit_DialogColor_ColorSelect:SetColorRGB(rperc,gperc,bperc);
        end

        -- RGB Sliders
        if ( not sender or (not (sender:GetName() == "QuiDicit_DialogColor_SliderRR")
                and not (sender:GetName() == "QuiDicit_DialogColor_SliderGG")
                and not (sender:GetName() == "QuiDicit_DialogColor_SliderBB"))) then
            QuiDicit_DialogColor_SliderRR:SetValue(255 - r);
            QuiDicit_DialogColor_SliderGG:SetValue(255 - g);
            QuiDicit_DialogColor_SliderBB:SetValue(255 - b);
        end

        -- preview ColorBox
        QuiDicit_DialogColor_Colorbox_Background:SetTexture(rperc,gperc,bperc);

        QuiDicit_DialogColorUpdate:SetText("0");
    end
end

function QuiDicit.DialogColor_Action()
    local action = tonumber(QuiDicit_DialogColorType:GetText());
    local name = QuiDicit_DialogColor_EditBoxCharacter:GetText();
    local group = QuiDicit_DialogColor_EditBoxGroup:GetText();
    local color = QuiDicit_DialogColor_EditBoxHex:GetText();

    if ( action == act.CHARCOLOR ) then
        QD.Character_ChangeColor(name, color);
        QD.printInfo(addonName .. ": \124cFF"..color..name .."\124r ".. L.info.MSG_COLORED .. ".");

    elseif ( action == act.CHARGROUP ) then
        if ( not QD.vigs[group] ) then
            QD.Group_ChangeColor(group, color);
        end
        QD.Character_ChangeGroup(name, group);
        QD.printInfo(addonName .. ": " .. name .. " " ..L.info.MSG_CHANGE_GROUP .. " " .. group .. ".");

    elseif ( action == act.GROUPCREATE ) then
        QD.Group_ChangeColor(group, color);
        QD.printInfo(addonName .. ": \124cFF"..color..group .."\124r ".. L.info.MSG_COLORED .. ".");

    elseif ( action == act.GROUPCOLOR ) then
        QD.Group_ChangeColor(group, color);
        QD.printInfo(addonName .. ": \124cFF"..color..group .."\124r ".. L.info.MSG_COLORED .. ".");

    elseif ( action == act.GROUPDELETE ) then
        QD.Group_Remove( group );
        QD.printInfo(addonName .. ": ".. group .." ".. L.info.MSG_REMOVED_VI);

    elseif ( action ==act.CHARUNCOLOR ) then
        QD.Character_ResetColor( name );
        QD.Character_Check();
        QD.printInfo(addonName .. ": " .. name .. " " .. L.info.MSG_RESET_COLOR);

    elseif ( action ==act.CHARUNGROUP ) then
        QD.Character_ResetGroup( name );
        QD.Character_Check();
        QD.printInfo(addonName .. ": " .. name .. " " .. L.info.MSG_RESET_GROUP);

    elseif ( action ==act.CHARDELETE ) then
        QD.Character_Remove( name );
        QD.printInfo(addonName .. ": ".. name .. " ".. L.info.MSG_REMOVED_VI);

    end
end

function QuiDicit.DialogColor_Unlock()
    QuiDicit.DialogColor_SetTitle( 0 , L.dialogcolors.TITLE );

    -- char and group, checkboxes
    QuiDicit_DialogColor_EditBoxCharacter:Show();
    QuiDicit_DialogColor_EditBoxGroup:Show();

    -- color settings
    QuiDicit_DialogColor_ColorSelect:Show();
    QuiDicit_DialogColor_Colorbox:Show();
    QuiDicit_DialogColor_SliderRR:Show();
    QuiDicit_DialogColor_SliderGG:Show();
    QuiDicit_DialogColor_SliderBB:Show();
    QuiDicit_DialogColor_EditBoxHex:Show();
end

function QuiDicit.DialogColor_SetTitle( typ, subtitle )
    if ( typ == 1 ) then --subtitle
        QuiDicit_DialogColorHeader:SetText(L.dialogcolors.TITLE .. ": " .. subtitle);
    else
        QuiDicit_DialogColorHeader:SetText(subtitle);
    end
end

function QuiDicit.DialogColor_Setup( action )
    if ( action == act.CHARCOLOR ) then
        QuiDicit.DialogColor_SetTitle( 1 , L.menu.MENU_CHARCOLOR );
        QuiDicit_DialogColor_EditBoxGroup:Hide();
        -- QuiDicit_DialogColor_CheckButtonGroup:Hide();

    elseif ( action == act.CHARGROUP ) then
        QuiDicit.DialogColor_SetTitle( 1 , L.menu.MENU_CHARGROUP );
        -- QuiDicit_DialogColor_CheckButtonChar:Hide();
        -- QuiDicit_DialogColor_CheckButtonGroup:Hide();

    elseif ( action == act.GROUPCREATE ) then
        QuiDicit.DialogColor_SetTitle( 1 , L.menu.MENU_GROUPCREATE );
        QuiDicit_DialogColor_EditBoxCharacter:Hide();

    elseif ( action == act.GROUPCOLOR ) then
        QuiDicit.DialogColor_SetTitle( 1 , L.menu.MENU_GROUPCREATE );
        QuiDicit_DialogColor_EditBoxCharacter:Hide();

    elseif ( action == act.CHARUNCOLOR ) then
        QuiDicit.DialogColor_SetTitle( 1 , L.menu.MENU_CHARUNCOLOR );
        QuiDicit_DialogColor_EditBoxGroup:Hide();
        -- QuiDicit_DialogColor_SliderOpacity:Hide();
        QuiDicit_DialogColor_ColorSelect:Hide();
        QuiDicit_DialogColor_Colorbox:Hide();
        QuiDicit_DialogColor_SliderRR:Hide();
        QuiDicit_DialogColor_SliderGG:Hide();
        QuiDicit_DialogColor_SliderBB:Hide();
        QuiDicit_DialogColor_EditBoxHex:Hide();

    elseif ( action == act.CHARUNGROUP ) then
        QuiDicit.DialogColor_SetTitle( 1 , L.menu.MENU_CHARUNGROUP );
        QuiDicit_DialogColor_EditBoxGroup:Hide();
        -- QuiDicit_DialogColor_SliderOpacity:Hide();
        QuiDicit_DialogColor_ColorSelect:Hide();
        QuiDicit_DialogColor_Colorbox:Hide();
        QuiDicit_DialogColor_SliderRR:Hide();
        QuiDicit_DialogColor_SliderGG:Hide();
        QuiDicit_DialogColor_SliderBB:Hide();
        QuiDicit_DialogColor_EditBoxHex:Hide();

    elseif ( action == act.CHARDELETE ) then
        QuiDicit.DialogColor_SetTitle( 1 , L.menu.MENU_CHARDELETE );
        QuiDicit_DialogColor_EditBoxGroup:Hide();
        -- QuiDicit_DialogColor_SliderOpacity:Hide();
        QuiDicit_DialogColor_ColorSelect:Hide();
        QuiDicit_DialogColor_Colorbox:Hide();
        QuiDicit_DialogColor_SliderRR:Hide();
        QuiDicit_DialogColor_SliderGG:Hide();
        QuiDicit_DialogColor_SliderBB:Hide();
        QuiDicit_DialogColor_EditBoxHex:Hide();

    end
end

function QuiDicit.DialogColor_Localize()
    QuiDicit_DialogColorHeader:SetText(L.dialogcolors.TITLE);
    QuiDicit_DialogColor_EditBoxCharacterText:SetText(L.dialogcolors.CHARNAME);
    QuiDicit_DialogColor_EditBoxGroup.text:SetText(L.dialogcolors.GROUPNAME);
    -- QuiDicit_DialogColor_CheckButtonChar.text:SetText(L.dialogcolors.COLORINDIVIDUAL);
    -- QuiDicit_DialogColor_CheckButtonGroup.text:SetText(L.dialogcolors.COLORGROUP);
    -- QuiDicit_DialogColor_SliderOpacityHeader:SetText(L.dialogcolors.LIGHT);
    QuiDicit_DialogColor_EditBoxHex.text:SetText(L.dialogcolors.HEX);
    QuiDicit_DialogColor_ButtonOK:SetText(L.dialogcolors.OK);
    QuiDicit_DialogColor_ButtonCANCEL:SetText(L.dialogcolors.CANCEL);
end