﻿local addonName, QD = ...; -- gets addon-local variables

local L = QD.LOCALIZATION;

----------------------------------------------------------------------------------------------------
-- Events

function QuiDicit.Events_OnLoad ( self )
    self:RegisterEvent( "ADDON_LOADED" );
    self:RegisterEvent( "PLAYER_LOGIN" );
    self:RegisterEvent( "PLAYER_ENTERING_WORLD" );
    -- self:RegisterEvent( "PLAYER_ALIVE" );
    self:RegisterEvent( "PLAYER_LEAVING_WORLD" );
    self:RegisterEvent( "PLAYER_LOGOUT" );
end

function QuiDicit.Events_OnEvent( self, event, ...)
    -- Loading the Game / Zoning in
    if (event == "ADDON_LOADED" and  ... == addonName) then
        -- Addon and saved variables loaded
        QD.Events_LoadVariables();

    elseif ( event == "PLAYER_LOGIN" ) then
        -- -- most game variables are accessible
        -- QD.start(self);
        QD.printInfo(addonName .. " v"..GetAddOnMetadata(addonName,"Version").. " " .. L.info.MSG_LOADED .. ". ("..QD.colors.chatcommand.."/qdic help|r). ");

    -- elseif ( event == "PLAYER_ENTERING_WORLD" ) then
        -- -- after PLAYER_LOGIN or after zoning

    -- elseif ( event == "PLAYER_ALIVE" ) then

    elseif ( event == "PLAYER_LOGOUT" ) then
        -- no access to player functionalities anymore
        -- prepare variables for saving
        QD.Events_SaveVariables();

    end
end

--/ Saves specific information
function QD.Events_SaveVariables()
    if ( not QuiDicitcore ) then
        QuiDicitCore = {};
    end

    QuiDicitCore["info"] = {};
    QuiDicitCore["info"]["version"] = GetAddOnMetadata(addonName,"Version");

    QuiDicitCore["config"] = {};
    QuiDicitCore["config"]["isOn"] = QD.on;
    QuiDicitCore["config"]["colorNames"] = QD.colorNames;
    QuiDicitCore["config"]["colorLines"] = QD.colorLines;
    QuiDicitCore["config"]["priority"] = QD.priority;
    QuiDicitCore["config"]["preText"] = QD.preText;
    QuiDicitCore["config"]["postText"] = QD.postText;

    QuiDicitCore["channels"] = {};
    QuiDicitCore["channels"] = QD.usedChannels;


    QuiDicitCore["vips"] = QD.vips;
    QuiDicitCore["vigs"] = QD.vigs;
end

--/ Loads specific information
function QD.Events_LoadVariables()
    if ( QuiDicitCore ~= nil ) then
        -- next initialisation, loads saved variables into local scope
        QD.on  = QuiDicitCore["config"]["isOn"];
        QD.colorNames  = QuiDicitCore["config"]["colorNames"];
        QD.colorLines  = QuiDicitCore["config"]["colorLines"];
        QD.priority    = QuiDicitCore["config"]["priority"];
        QD.preText     = QuiDicitCore["config"]["preText"];
        QD.postText    = QuiDicitCore["config"]["postText"];

        QD.usedChannels = QuiDicitCore["channels"];

        QD.vips = QuiDicitCore["vips"];
        QD.vigs = QuiDicitCore["vigs"];
    else
        -- first initialisation, use default values
    end

    QuiDicitCore = {};
end